pub struct Stat {
stat_type_entry: StatTypeEntryRef,
value: &'static dyn StatValueRegistryEntry,
}Expand description
Identifies a particular stat whose generic type is erased. This stat can also be encoded to and decoded from the network.
This is analogous to Vanilla’s Stat<?>.
Fields
stat_type_entry: StatTypeEntryRefvalue: &'static dyn StatValueRegistryEntryImplementations
Sourceimpl Stat
impl Stat
Sourcepub fn new<R: RegistryExt>(
stat_type: StatTypeRef<R>,
value: &'static R::Entry,
) -> Selfwhere
R::Entry: StatValueRegistryEntry,
pub fn new<R: RegistryExt>(
stat_type: StatTypeRef<R>,
value: &'static R::Entry,
) -> Selfwhere
R::Entry: StatValueRegistryEntry,
Attempts to create a new erased stat from its type and value with type safety.
This function panics if the stat type provided is unregistered
with the StatTypeRegistry.
Sourcepub const fn from_erased(
stat_type_entry: StatTypeEntryRef,
value: &'static dyn StatValueRegistryEntry,
) -> Self
pub const fn from_erased( stat_type_entry: StatTypeEntryRef, value: &'static dyn StatValueRegistryEntry, ) -> Self
Creates a new erased stat from its erased type and value.
Sourcepub const fn stat_type(&self) -> StatTypeEntryRef
pub const fn stat_type(&self) -> StatTypeEntryRef
Gets the type-erased stat type of this stat.
Sourcepub const fn stat_value(&self) -> &'static dyn StatValueRegistryEntry
pub const fn stat_value(&self) -> &'static dyn StatValueRegistryEntry
Gets the type-erased stat value of this stat.
Sourcepub const fn stat_type_key(&self) -> &Identifier
pub const fn stat_type_key(&self) -> &Identifier
Gets the key of the stat type of this stat.
Sourcepub fn stat_value_key(&self) -> &Identifier
pub fn stat_value_key(&self) -> &Identifier
Gets the key of the stat value of this stat.
Sourcepub fn stat_type_id(&self) -> usize
pub fn stat_type_id(&self) -> usize
Gets the registry ID of the stat type of this stat.
Sourcepub fn stat_value_id(&self) -> usize
pub fn stat_value_id(&self) -> usize
Gets the registry ID of the stat value of this stat.