pub struct StatValueRegistryData {
value: &'static dyn StatValueRegistry,
}Expand description
A type-erased registry whose values can be used for identifying a particular stat.
Registries retain their concrete Rust type and can be recovered with Self::downcast_ref.
Fields
value: &'static dyn StatValueRegistryImplementations
Sourceimpl StatValueRegistryData
impl StatValueRegistryData
Sourcepub fn new(value: &'static dyn StatValueRegistry) -> Self
pub fn new(value: &'static dyn StatValueRegistry) -> Self
Erases the type of the provided registry.
Sourcepub fn downcast_ref<R: StatValueRegistry + DowncastType>(
&self,
) -> Option<&'static R>
pub fn downcast_ref<R: StatValueRegistry + DowncastType>( &self, ) -> Option<&'static R>
Returns the concrete registry when it has type R.
Sourcepub fn type_key(&self) -> DowncastTypeKey
pub fn type_key(&self) -> DowncastTypeKey
Returns the concrete type key of the registry involved in the data.